// commitlint.config.js
module.exports = {
  extends: ["@commitlint/config-conventional"],
  // Optional: make it stricter (recommended)
  rules: {
    "breaking-change-exclamation-mark": [2, "always"],
    "subject-case": [
      2,
      "always",
      ["sentence-case", "start-case", "pascal-case", "upper-case"],
    ],
    "type-enum": [
      2,
      "always",
      [
        "build",
        "chore",
        "ci",
        "docs",
        "feat",
        "fix",
        "perf",
        "refactor",
        "revert",
        "style",
        "test",
      ],
    ],
  },
};
